@@ -13,18 +13,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import gettext
 from xml.dom import minidom
 
 import mock
-from oslo.i18n import _lazy
 import webob.dec
-import webob.exc
 
 from cinder.api import common
 from cinder.api.openstack import wsgi
-from cinder import exception
-from cinder import i18n as cinder_i18n
 from cinder.i18n import _
 from cinder.openstack.common import jsonutils
 from cinder import test
@@ -35,12 +30,6 @@ class TestFaults(test.TestCase):
 
     def setUp(self):
         super(TestFaults, self).setUp()
-        back_use_lazy = _lazy.USE_LAZY
-        cinder_i18n.enable_lazy()
-        self.addCleanup(self._restore_use_lazy, back_use_lazy)
-
-    def _restore_use_lazy(self, back_use_lazy):
-        _lazy.USE_LAZY = back_use_lazy
 
     def _prepare_xml(self, xml_string):
         """Remove characters from string which hinder XML equality testing."""
@@ -142,44 +131,6 @@ class TestFaults(test.TestCase):
         self.assertIn(("Mensaje traducido"), resp.body)
         self.stubs.UnsetAll()
 
-    @mock.patch('oslo.i18n._message.gettext.translation')
-    def test_raise_invalid_with_localized_explanation(self, mock_translation):
-        msg_template = _("Invalid input: %(reason)s")
-        reason = _("Value is invalid")
-
-        class MockESTranslations(gettext.GNUTranslations):
-            def ugettext(self, msgid):
-                if "Invalid input" in msgid:
-                    return "Entrada invalida: %(reason)s"
-                elif "Value is invalid" in msgid:
-                    return "El valor es invalido"
-                return msgid
-
-            def gettext(self, msgid):
-                return self.ugettext(msgid)
-
-        def translation(domain, localedir=None, languages=None, fallback=None):
-            return MockESTranslations()
-
-        mock_translation.side_effect = translation
-
-        @webob.dec.wsgify
-        def raiser(req):
-            class MyInvalidInput(exception.InvalidInput):
-                message = msg_template
-
-            ex = MyInvalidInput(reason=reason)
-            raise wsgi.Fault(exception.ConvertedException(code=ex.code,
-                                                          explanation=ex.msg))
-
-        req = webob.Request.blank("/.json")
-        resp = req.get_response(raiser)
-        self.assertEqual(resp.content_type, "application/json")
-        self.assertEqual(resp.status_int, 400)
-        # This response was comprised of Message objects from two different
-        # exceptions, here we are testing that both got translated
-        self.assertIn("Entrada invalida: El valor es invalido", resp.body)
-
     def test_fault_has_status_int(self):
         """Ensure the status_int is set correctly on faults."""
         fault = wsgi.Fault(webob.exc.HTTPBadRequest(explanation='what?'))
