@@ -40,6 +40,7 @@ from cinder.volume.drivers.netapp.options import netapp_connection_opts
 from cinder.volume.drivers.netapp.options import netapp_provisioning_opts
 from cinder.volume.drivers.netapp.options import netapp_transport_opts
 from cinder.volume.drivers.netapp import ssc_utils
+from cinder.volume.drivers.netapp import utils
 
 LOG = logging.getLogger("cinder.volume.driver")
 
@@ -555,6 +556,7 @@ class NetAppDirectCmodeISCSIDriverTestCase(test.TestCase):
         self.stubs.Set(
             ssc_utils, 'refresh_cluster_ssc',
             lambda a, b, c, synchronous: None)
+        self.mock_object(utils, 'OpenStackInfo')
         configuration = self._set_config(create_configuration())
         driver = common.NetAppDriver(configuration=configuration)
         self.stubs.Set(httplib, 'HTTPConnection',
@@ -571,13 +573,58 @@ class NetAppDirectCmodeISCSIDriverTestCase(test.TestCase):
         configuration.netapp_password = 'pass'
         configuration.netapp_server_hostname = '127.0.0.1'
         configuration.netapp_transport_type = 'http'
-        configuration.netapp_server_port = '80'
+        configuration.netapp_server_port = None
         configuration.netapp_vserver = 'openstack'
         return configuration
 
     def test_connect(self):
         self.driver.check_for_setup_error()
 
+    def test_do_setup_all_default(self):
+        configuration = self._set_config(create_configuration())
+        driver = common.NetAppDriver(configuration=configuration)
+        driver._do_custom_setup = mock.Mock()
+        driver.do_setup(context='')
+        self.assertEqual('80', driver.client.get_port())
+        self.assertEqual('http', driver.client.get_transport_type())
+
+    def test_do_setup_http_default_port(self):
+        configuration = self._set_config(create_configuration())
+        configuration.netapp_transport_type = 'http'
+        driver = common.NetAppDriver(configuration=configuration)
+        driver._do_custom_setup = mock.Mock()
+        driver.do_setup(context='')
+        self.assertEqual('80', driver.client.get_port())
+        self.assertEqual('http', driver.client.get_transport_type())
+
+    def test_do_setup_https_default_port(self):
+        configuration = self._set_config(create_configuration())
+        configuration.netapp_transport_type = 'https'
+        driver = common.NetAppDriver(configuration=configuration)
+        driver._do_custom_setup = mock.Mock()
+        driver.do_setup(context='')
+        self.assertEqual('443', driver.client.get_port())
+        self.assertEqual('https', driver.client.get_transport_type())
+
+    def test_do_setup_http_non_default_port(self):
+        configuration = self._set_config(create_configuration())
+        configuration.netapp_server_port = 81
+        driver = common.NetAppDriver(configuration=configuration)
+        driver._do_custom_setup = mock.Mock()
+        driver.do_setup(context='')
+        self.assertEqual('81', driver.client.get_port())
+        self.assertEqual('http', driver.client.get_transport_type())
+
+    def test_do_setup_https_non_default_port(self):
+        configuration = self._set_config(create_configuration())
+        configuration.netapp_transport_type = 'https'
+        configuration.netapp_server_port = 446
+        driver = common.NetAppDriver(configuration=configuration)
+        driver._do_custom_setup = mock.Mock()
+        driver.do_setup(context='')
+        self.assertEqual('446', driver.client.get_port())
+        self.assertEqual('https', driver.client.get_transport_type())
+
     def test_create_destroy(self):
         self.driver.create_volume(self.volume)
         self.driver.delete_volume(self.volume)
@@ -624,6 +671,7 @@ class NetAppDirectCmodeISCSIDriverTestCase(test.TestCase):
             raise AssertionError('Target portal is none')
 
     def test_vol_stats(self):
+        self.mock_object(utils, 'provide_ems')
         self.driver.get_volume_stats(refresh=True)
         stats = self.driver._stats
         self.assertEqual(stats['vendor_name'], 'NetApp')
@@ -682,6 +730,7 @@ class NetAppDriverNegativeTestCase(test.TestCase):
         super(NetAppDriverNegativeTestCase, self).setUp()
 
     def test_incorrect_family(self):
+        self.mock_object(utils, 'OpenStackInfo')
         configuration = create_configuration()
         configuration.netapp_storage_family = 'xyz_abc'
         try:
@@ -691,6 +740,7 @@ class NetAppDriverNegativeTestCase(test.TestCase):
             pass
 
     def test_incorrect_protocol(self):
+        self.mock_object(utils, 'OpenStackInfo')
         configuration = create_configuration()
         configuration.netapp_storage_family = 'ontap'
         configuration.netapp_storage_protocol = 'ontap'
@@ -701,6 +751,7 @@ class NetAppDriverNegativeTestCase(test.TestCase):
             pass
 
     def test_non_netapp_driver(self):
+        self.mock_object(utils, 'OpenStackInfo')
         configuration = create_configuration()
         common.netapp_unified_plugin_registry['test_family'] =\
             {'iscsi': 'cinder.volume.drivers.arbitrary.IscsiDriver'}
@@ -1141,6 +1192,7 @@ class NetAppDirect7modeISCSIDriverTestCase_NV(
         super(NetAppDirect7modeISCSIDriverTestCase_NV, self).setUp()
 
     def _custom_setup(self):
+        self.mock_object(utils, 'OpenStackInfo')
         configuration = self._set_config(create_configuration())
         driver = common.NetAppDriver(configuration=configuration)
         self.stubs.Set(httplib, 'HTTPConnection',
@@ -1158,7 +1210,7 @@ class NetAppDirect7modeISCSIDriverTestCase_NV(
         configuration.netapp_password = 'pass'
         configuration.netapp_server_hostname = '127.0.0.1'
         configuration.netapp_transport_type = 'http'
-        configuration.netapp_server_port = '80'
+        configuration.netapp_server_port = None
         return configuration
 
     def test_create_on_select_vol(self):
@@ -1191,6 +1243,7 @@ class NetAppDirect7modeISCSIDriverTestCase_WV(
         super(NetAppDirect7modeISCSIDriverTestCase_WV, self).setUp()
 
     def _custom_setup(self):
+        self.mock_object(utils, 'OpenStackInfo')
         configuration = self._set_config(create_configuration())
         driver = common.NetAppDriver(configuration=configuration)
         self.stubs.Set(httplib, 'HTTPConnection',
@@ -1208,7 +1261,7 @@ class NetAppDirect7modeISCSIDriverTestCase_WV(
         configuration.netapp_password = 'pass'
         configuration.netapp_server_hostname = '127.0.0.1'
         configuration.netapp_transport_type = 'http'
-        configuration.netapp_server_port = '80'
+        configuration.netapp_server_port = None
         configuration.netapp_vfiler = 'openstack'
         return configuration
 
