@@ -349,6 +349,32 @@ class RBDTestCase(test.TestCase):
                     self.assertEqual(RAISED_EXCEPTIONS,
                                      [self.mock_rbd.ImageBusy])
 
+    @common_mocks
+    def test_delete_volume_not_found(self):
+        self.mock_rbd.Image.list_snaps = mock.Mock()
+        self.mock_rbd.Image.list_snaps.return_value = []
+        self.mock_rbd.Image.unprotect_snap = mock.Mock()
+
+        self.mock_rbd.RBD.remove = mock.Mock()
+        self.mock_rbd.RBD.remove.side_effect = self.mock_rbd.ImageNotFound
+
+        with mock.patch.object(self.driver, '_get_clone_info') as \
+                mock_get_clone_info:
+            mock_get_clone_info.return_value = (None, None, None)
+            with mock.patch.object(self.driver, '_delete_backup_snaps') as \
+                    mock_delete_backup_snaps:
+                with mock.patch.object(driver, 'RADOSClient') as \
+                        mock_rados_client:
+                    self.assertIsNone(self.driver.delete_volume(self.volume))
+                    mock_get_clone_info.assert_called_once()
+                    self.mock_rbd.Image.list_snaps.assert_called_once()
+                    mock_rados_client.assert_called_once()
+                    mock_delete_backup_snaps.assert_called_once()
+                    self.assertFalse(self.mock_rbd.Image.unprotect_snap.called)
+                    # Make sure the exception was raised
+                    self.assertEqual(RAISED_EXCEPTIONS,
+                                     [self.mock_rbd.ImageNotFound])
+
     @common_mocks
     def test_create_snapshot(self):
         proxy = self.mock_proxy.return_value
